# NFEM Teaching Tool

![PyPI](https://img.shields.io/pypi/v/nfem) ![PyPI - Downloads](https://img.shields.io/pypi/dm/nfem) [![Coverage Status](https://coveralls.io/repos/github/StatikTUM/nfem/badge.svg?branch=master&service=github)](https://coveralls.io/github/StatikTUM/nfem?branch=master) ![CI](https://github.com/StatikTUM/nfem/workflows/CI/badge.svg) [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/StatikTUM/nfem/master?filepath=examples) [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/StatikTUM/nfem/)

This is a lightweight python tool build for teaching non linear FEM analysis of 3D truss structures.

## Installation

Install [Anaconda](https://www.anaconda.com/distribution/), open the Anaconda console and execute the following command:

```shell
pip install nfem
```
